OH_AudioDecoder_SetCallback

Function OH_AudioDecoder_SetCallback 

pub unsafe extern "C" fn OH_AudioDecoder_SetCallback(
    codec: *mut OH_AVCodec,
    callback: OH_AVCodecAsyncCallback,
    userData: *mut c_void,
) -> OH_AVErrCode
👎Deprecated since 11
Set the asynchronous callback function so that your application can respond to the events generated by the audio decoder. This interface must be called before Prepare is called.

Required System Capabilities: SystemCapability.Multimedia.Media.AudioDecoder

Arguments

  • codec - Pointer to an OH_AVCodec instance

  • callback - A collection of all callback functions, see OH_AVCodecAsyncCallback

  • userData - User specific data

Returns

  • Returns AV_ERR_OK if the execution is successful, otherwise returns a specific error code, refer to OH_AVErrCode

Deprecated since 11 OH_AudioCodec_RegisterCallback

Available since API-level: 9