#[repr(C)]pub struct OH_AVCodecAsyncCallback {
pub onError: OH_AVCodecOnError,
pub onStreamChanged: OH_AVCodecOnStreamChanged,
pub onNeedInputData: OH_AVCodecOnNeedInputData,
pub onNeedOutputData: OH_AVCodecOnNewOutputData,
}👎Deprecated since 11
A collection of all asynchronous callback function pointers in OH_AVCodec. Register an instance of this structure to the OH_AVCodec instance, and process the information reported through the callback to ensure the normal operation of OH_AVCodec.
Required System Capabilities: SystemCapability.Multimedia.Media.CodecBase
Arguments
-
onError- Monitor OH_AVCodec operation errors, refer toOH_AVCodecOnError -
onStreamChanged- Monitor codec stream information, refer toOH_AVCodecOnStreamChanged -
onNeedInputData- Monitoring codec requires input data, refer toOH_AVCodecOnNeedInputData -
onNeedOutputData- Monitor codec to generate output data, refer toOH_AVCodecOnNewOutputData
Deprecated since 11 OH_AVCodecCallback
Available since API-level: 9
Fields
onError: OH_AVCodecOnError👎Deprecated since 11
onStreamChanged: OH_AVCodecOnStreamChanged👎Deprecated since 11
onNeedInputData: OH_AVCodecOnNeedInputData👎Deprecated since 11
onNeedOutputData: OH_AVCodecOnNewOutputData👎Deprecated since 11