#[repr(C)]pub struct OH_AVCodecCallback {
pub onError: OH_AVCodecOnError,
pub onStreamChanged: OH_AVCodecOnStreamChanged,
pub onNeedInputBuffer: OH_AVCodecOnNeedInputBuffer,
pub onNewOutputBuffer: OH_AVCodecOnNewOutputBuffer,
}Available on crate feature
api-11 only.Expand description
A collection of all asynchronous callback function pointers in OH_AVCodec. Register an instance of this structure to the OH_AVCodec instance, and process the information reported through the callback to ensure the normal operation of OH_AVCodec.
Required System Capabilities: SystemCapability.Multimedia.Media.CodecBase
Arguments
-
onError- Monitor OH_AVCodec operation errors, refer toOH_AVCodecOnError -
onStreamChanged- Monitor codec stream information, refer toOH_AVCodecOnStreamChanged -
onNeedInputBuffer- Monitoring codec requires input buffer, refer toOH_AVCodecOnNeedInputBuffer -
onNewOutputBuffer- Monitor codec to generate output buffer, refer toOH_AVCodecOnNewOutputBuffer
Available since API-level: 11
Fields
onError: OH_AVCodecOnErroronStreamChanged: OH_AVCodecOnStreamChangedonNeedInputBuffer: OH_AVCodecOnNeedInputBufferonNewOutputBuffer: OH_AVCodecOnNewOutputBufferTrait Implementations
Sourceimpl Clone for OH_AVCodecCallback
impl Clone for OH_AVCodecCallback
Sourcefn clone(&self) -> OH_AVCodecCallback
fn clone(&self) -> OH_AVCodecCallback
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OH_AVCodecCallback
impl Debug for OH_AVCodecCallback
impl Copy for OH_AVCodecCallback