OH_VideoDecoder_GetOutputDescription

Function OH_VideoDecoder_GetOutputDescription 

pub unsafe extern "C" fn OH_VideoDecoder_GetOutputDescription(
    codec: *mut OH_AVCodec,
) -> *mut OH_AVFormat
Get the description information of the output data of the decoder, refer to OH_AVFormat It should be noted that the life cycle of the OH_AVFormat instance pointed to by the return value * needs to be manually released by the caller.

Required System Capabilities: SystemCapability.Multimedia.Media.VideoDecoder

Arguments

  • codec - Pointer to an OH_AVCodec instance

Returns

  • Returns a pointer to an OH_AVFormat instance. Return nullptr if the decoder is nullptr or invaild.

Available since API-level: 9