pub unsafe extern "C" fn OH_VideoDecoder_RenderOutputData(
codec: *mut OH_AVCodec,
index: u32,
) -> OH_AVErrCode👎Deprecated since 11
Return the processed output Buffer to the decoder, and notify the decoder to finish rendering the decoded data contained in the Buffer on the output Surface. If the output surface is not configured before, calling this interface only returns the output buffer corresponding to the specified index to the decoder.
Required System Capabilities: SystemCapability.Multimedia.Media.VideoDecoder
Arguments
-
codec- Pointer to an OH_AVCodec instance -
index- The index value corresponding to the output Buffer
Returns
- Returns AV_ERR_OK if the execution is successful,
otherwise returns a specific error code, refer to
OH_AVErrCode. [AV_ERR_NO_MEMORY], instance has already released. [AV_ERR_INVALID_VAL], the decoder is nullptr or invalid. Buffer index should be given by [OH_AVCodecOnNewOutputData]. [AV_ERR_UNKNOWN], unknown error. [AV_ERR_SERVICE_DIED], avcodec service is died. [AV_ERR_INVALID_STATE], this interface was called in invalid state.
Deprecated since 11 OH_VideoDecoder_RenderOutputBuffer
Available since API-level: 9