OH_AVTranscoder_SetProgressUpdateCallback

Function OH_AVTranscoder_SetProgressUpdateCallback 

pub unsafe extern "C" fn OH_AVTranscoder_SetProgressUpdateCallback(
    transcoder: *mut OH_AVTranscoder,
    callback: OH_AVTranscoder_OnProgressUpdate,
    userData: *mut c_void,
) -> OH_AVErrCode
Available on crate feature api-20 only.
Set the progress updating callback function so that your application can respond to the progress updating events generated by the avtranscoder. This interface must be called before Start is called.

Arguments

{OH_AVTranscoder*} transcoder Pointer to an OH_AVTranscoder instance

{OH_AVTranscoder_OnProgressUpdate} callback Uri callback function, see OH_AVTranscoder_OnProgressUpdate

{void*} userData Pointer to user specific data

Returns

  • Function result code. [AV_ERR_OK] if the execution is successful. [AV_ERR_INVALID_VAL] if input transcoder is nullptr or input callback is nullptr.

Available since API-level: 20