pub unsafe extern "C" fn OH_AudioDecoder_GetOutputDescription(
codec: *mut OH_AVCodec,
) -> *mut OH_AVFormat👎Deprecated since 11
Get the description information of the output data of the decoder, refer to OH_AVFormat for details.
It should be noted that the life cycle of the OH_AVFormat instance pointed to by the return value * needs to
be manually released by the caller
Required System Capabilities: SystemCapability.Multimedia.Media.AudioDecoder
Arguments
codec- Pointer to an OH_AVCodec instance
Returns
- Returns the OH_AVFormat handle pointer, the life cycle is refreshed with the next GetOutputMediaDescription, or destroyed with OH_AVCodec;
Deprecated since 11 OH_AudioCodec_GetOutputDescription
Available since API-level: 9